/*
  The following C macro's allow direct coding of instructions.

  Note that direct coded instructions are different from inline
  assembly seen from the compiler. The compiler will view the
  instruction codes as values only and not as instructions. All high
  level properties are lost. The compiler will reset optimization,
  bank updating, etc. after a DW statement.

  Example usage:

  1. In DW statements. 
    #asm
     DW __SLEEP                   // Enter sleep mode
     DW __MOVWF(__INDF0)          // Store indirectly
     DW __ANDLW(0x80)             // W = W & 0x80;
     DW __DECF(__FSR0,__F)        // Decrement FSR0
     DW __BCF(__ALUSTA,__Carry)   // Clear Carry bit
     DW __GOTO(0)                 // Goto address 0
    #endasm

  2. In cdata statements:
    #pragma cdata[1] = __GOTO(0x1FF)
*/


#ifndef HEX_CODES_H7A
#define HEX_CODES_H7A

#if __CoreSet__ == 1700  ||  __CoreSet__ == 1742

#define __F      1
#define __W      0
#define __INDF0    0
#define __FSR0     1
#define __PCL      2
#define __PCLATH   3
#define __ALUSTA   4
#define __T0STA    5
#define __CPUSTA   6
#define __INTSTA   7
#define __INDF1    8
#define __FSR1     9
#define __WREG    10
#define __TMR0L   11
#define __TMR0H   12
#define __TBLPTRL 13
#define __TBLPTRH 14
#define __BSR     15
#define __PORTA   16
#define __TRISA   17
#define __PORTB   18
#define __RCSTA1  19
#define __RCREG1  20
#define __TXSTA1  21
#define __TXREG1  22
#define __SPBRG1  23
#define __PRODL   24
#define __PRODH   25
#define __Carry    0
#define __DC       1
#define __Zero     2
#define __Overflow 3

#define __NOP            0x0000
#define __MOVWF(f)      (0x0100+((f)&0xFF))
#define __SUBWF(f,d)    (0x0400+((f)&0xFF)+((d&1L)<<8))
#define __DECF(f,d)     (0x0600+((f)&0xFF)+((d&1L)<<8))
#define __IORWF(f,d)    (0x0800+((f)&0xFF)+((d&1L)<<8))
#define __ANDWF(f,d)    (0x0A00+((f)&0xFF)+((d&1L)<<8))
#define __XORWF(f,d)    (0x0C00+((f)&0xFF)+((d&1L)<<8))
#define __ADDWF(f,d)    (0x0E00+((f)&0xFF)+((d&1L)<<8))
#define __COMF(f,d)     (0x1200+((f)&0xFF)+((d&1L)<<8))
#define __INCF(f,d)     (0x1400+((f)&0xFF)+((d&1L)<<8))
#define __DECFSZ(f,d)   (0x1600+((f)&0xFF)+((d&1L)<<8))
#define __RRCF(f,d)     (0x1800+((f)&0xFF)+((d&1L)<<8))
#define __RLCF(f,d)     (0x1A00+((f)&0xFF)+((d&1L)<<8))
#define __SWAPF(f,d)    (0x1C00+((f)&0xFF)+((d&1L)<<8))
#define __INCFSZ(f,d)   (0x1E00+((f)&0xFF)+((d&1L)<<8))
#define __BCF(f,b)      (0x8800+((f)&0xFF)+(((b)&7L)<<8))
#define __BSF(f,b)      (0x8000+((f)&0xFF)+(((b)&7L)<<8))
#define __BTFSC(f,b)    (0x9800+((f)&0xFF)+(((b)&7L)<<8))
#define __BTFSS(f,b)    (0x9000+((f)&0xFF)+(((b)&7L)<<8))
#define __SLEEP          0x0003
#define __CLRWDT         0x0004
#define __RETLW(k)      (0xB600+((k)&0xFF))
#define __CALL(a)       (0xE000+((a)&0x1FFF))
#define __GOTO(a)       (0xC000+((a)&0x1FFF))
#define __MOVLW(k)      (0xB000+((k)&0xFF))
#define __IORLW(k)      (0xB300+((k)&0xFF))
#define __ANDLW(k)      (0xB500+((k)&0xFF))
#define __XORLW(k)      (0xB400+((k)&0xFF))
#define __ADDLW(k)      (0xB100+((k)&0xFF))
#define __RETFIE         0x0005
#define __RETURN         0x0002
#define __SUBLW(k)      (0xB200+((k)&0xFF))
#define __ADDWFC(f,d)   (0x1000+((f)&0xFF)+((d&1L)<<8))
#define __SUBWFB(f,d)   (0x0200+((f)&0xFF)+((d&1L)<<8))
#define __CLRF(f,d)     (0x2800+((f)&0xFF)+((d&1L)<<8))
#define __SETF(f,d)     (0x2A00+((f)&0xFF)+((d&1L)<<8))
#define __NEGW(f,d)     (0x2C00+((f)&0xFF)+((d&1L)<<8))
#define __DAW(f,d)      (0x2E00+((f)&0xFF)+((d&1L)<<8))
#define __RLNCF(f,d)    (0x2200+((f)&0xFF)+((d&1L)<<8))
#define __RRNCF(f,d)    (0x2000+((f)&0xFF)+((d&1L)<<8))
#define __DCFSNZ(f,d)   (0x2600+((f)&0xFF)+((d&1L)<<8))
#define __INFSNZ(f,d)   (0x2400+((f)&0xFF)+((d&1L)<<8))
#define __CPFSEQ(f)     (0x3100+((f)&0xFF))
#define __CPFSGT(f)     (0x3200+((f)&0xFF))
#define __CPFSLT(f)     (0x3000+((f)&0xFF))
#define __TSTFSZ(f)     (0x3300+((f)&0xFF))
#define __LCALL(a)      (0xB700+((a)&0xFF))
#define __BTG(f,b)      (0x3800+((f)&0xFF)+(((b)&7L)<<8))
#define __MOVLB(k)      (0xB800+((k)&0xF))
#define __MOVFP(f,p)    (0x6000+((f)&0xFF)+(((p)&0x1FL)<<8))
#define __MOVPF(p,f)    (0x4000+((f)&0xFF)+(((p)&0x1FL)<<8))
#define __TABLRD(t,i,f) (0xA800+((f)&0xFF)+(((i)&1L)<<8)+(((t)&1L)<<9))
#define __TABLWT(t,i,f) (0xAC00+((f)&0xFF)+(((i)&1L)<<8)+(((t)&1L)<<9))
#define __TLRD(t,f)     (0xA000+((f)&0xFF)+(((t)&1L)<<9))
#define __TLWT(t,f)     (0xA400+((f)&0xFF)+(((t)&1L)<<9))

#if __CoreSet__ == 1700
#define __MULWF(f)      (0x3400+((f)&0xFF))
#define __MULLW(k)      (0xBC00+((k)&0xFF))
#define __MOVLR(k)      (0xBA00+(((k)&0xF)<<4))
#endif

#endif

#endif
